==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fIf__5facmpne.h <==
// class soot.coffi.Instruction_If_acmpne

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class f802dd766363a559 soot_coffi_Instruction__5fIf__5facmpne
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch
// @dep_class 6bcdce6545109d8e soot_coffi_Instruction__5fintbranch

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintbranch

#include "soot/coffi/Instruction__5fintbranch.h"

#ifndef _JC_soot_coffi_Instruction__5fIf__5facmpne_H_
#define _JC_soot_coffi_Instruction__5fIf__5facmpne_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIf__5facmpne$sub_refs	_jc_soot_coffi_Instruction__5fIf__5facmpne$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5facmpne$sub_nonrefs	_jc_soot_coffi_Instruction__5fIf__5facmpne$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5facmpne$refs	_jc_soot_coffi_Instruction__5fIf__5facmpne$refs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5facmpne$nonrefs	_jc_soot_coffi_Instruction__5fIf__5facmpne$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5facmpne$object	_jc_soot_coffi_Instruction__5fIf__5facmpne$object;

typedef const struct _jc_soot_coffi_Instruction__5fIf__5facmpne$vmethods	_jc_soot_coffi_Instruction__5fIf__5facmpne$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIf__5facmpne$vtable	_jc_soot_coffi_Instruction__5fIf__5facmpne$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIf__5facmpne$vtype	_jc_soot_coffi_Instruction__5fIf__5facmpne$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIf__5facmpne$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIf__5facmpne$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIf__5facmpne$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIf__5facmpne$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
	_jc_soot_coffi_Instruction__5fintbranch$vmethods	soot_coffi_Instruction__5fintbranch;
	_jc_soot_coffi_Instruction__5fIf__5facmpne$vmethods	soot_coffi_Instruction__5fIf__5facmpne;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIf__5facmpne$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIf__5facmpne$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIf__5facmpne$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIf__5facmpne$refs {
    _jc_soot_coffi_Instruction__5fIf__5facmpne$sub_refs	soot_coffi_Instruction__5fIf__5facmpne;
    _jc_soot_coffi_Instruction__5fintbranch$sub_refs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIf__5facmpne$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIf__5facmpne$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction__5fintbranch$sub_nonrefs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fIf__5facmpne$sub_nonrefs	soot_coffi_Instruction__5fIf__5facmpne;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIf__5facmpne$object {
	_jc_soot_coffi_Instruction__5fIf__5facmpne$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIf__5facmpne$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIf__5facmpne$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIf__5facmpne$vtype _jc_soot_coffi_Instruction__5fIf__5facmpne$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIf__5facmpne, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIf__5facmpne$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIf__5facmpne_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fIf__5facmpne.h <==
// class soot.coffi.Instruction_If_acmpne

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class f802dd766363a559 soot_coffi_Instruction__5fIf__5facmpne
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch
// @dep_class 6bcdce6545109d8e soot_coffi_Instruction__5fintbranch

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintbranch

#include "soot/coffi/Instruction__5fintbranch.h"

#ifndef _JC_soot_coffi_Instruction__5fIf__5facmpne_H_
#define _JC_soot_coffi_Instruction__5fIf__5facmpne_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIf__5facmpne$sub_refs	_jc_soot_coffi_Instruction__5fIf__5facmpne$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5facmpne$sub_nonrefs	_jc_soot_coffi_Instruction__5fIf__5facmpne$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5facmpne$refs	_jc_soot_coffi_Instruction__5fIf__5facmpne$refs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5facmpne$nonrefs	_jc_soot_coffi_Instruction__5fIf__5facmpne$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIf__5facmpne$object	_jc_soot_coffi_Instruction__5fIf__5facmpne$object;

typedef const struct _jc_soot_coffi_Instruction__5fIf__5facmpne$vmethods	_jc_soot_coffi_Instruction__5fIf__5facmpne$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIf__5facmpne$vtable	_jc_soot_coffi_Instruction__5fIf__5facmpne$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIf__5facmpne$vtype	_jc_soot_coffi_Instruction__5fIf__5facmpne$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIf__5facmpne$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIf__5facmpne$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIf__5facmpne$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIf__5facmpne$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
	_jc_soot_coffi_Instruction__5fintbranch$vmethods	soot_coffi_Instruction__5fintbranch;
	_jc_soot_coffi_Instruction__5fIf__5facmpne$vmethods	soot_coffi_Instruction__5fIf__5facmpne;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIf__5facmpne$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIf__5facmpne$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIf__5facmpne$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIf__5facmpne$refs {
    _jc_soot_coffi_Instruction__5fIf__5facmpne$sub_refs	soot_coffi_Instruction__5fIf__5facmpne;
    _jc_soot_coffi_Instruction__5fintbranch$sub_refs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIf__5facmpne$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIf__5facmpne$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction__5fintbranch$sub_nonrefs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fIf__5facmpne$sub_nonrefs	soot_coffi_Instruction__5fIf__5facmpne;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIf__5facmpne$object {
	_jc_soot_coffi_Instruction__5fIf__5facmpne$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIf__5facmpne$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIf__5facmpne$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIf__5facmpne$vtype _jc_soot_coffi_Instruction__5fIf__5facmpne$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIf__5facmpne, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIf__5facmpne$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIf__5facmpne_H_ */
